@@ -410,9 +410,10 @@ invalidated text."
 		    (assq buffer orig)
 		    (> jit-lock-context-unfontify-pos (alist-get buffer orig)))
 	   (with-silent-modifications
-	     (put-text-property (alist-get buffer orig)
-				jit-lock-context-unfontify-pos
-				'indent-bars-font-lock-pending t)))))))
+	     (without-restriction
+	       (put-text-property (alist-get buffer orig)
+				  jit-lock-context-unfontify-pos
+				  'indent-bars-font-lock-pending t))))))))
 
 (defun indent-bars-ts--font-lock-inhibit (beg end)
   "Check if font-lock is needed on the region between BEG and END.
